@@ -38,16 +38,16 @@
 
 static const GDBusErrorEntry xfconf_daemon_dbus_error_entries[] = 
 {
-    { XFCONF_ERROR_UNKNOWN, "org.xfce.Xfconf.Error.Unknown" },
-    { XFCONF_ERROR_CHANNEL_NOT_FOUND, "org.xfce.Xfconf.Error.ChannelNotFound" },
-    { XFCONF_ERROR_PROPERTY_NOT_FOUND, "org.xfce.Xfconf.Error.PropertyNotFound" },
-    { XFCONF_ERROR_READ_FAILURE, "org.xfce.Xfconf.Error.ReadFailure" },
-    { XFCONF_ERROR_WRITE_FAILURE, "org.xfce.Xfconf.Error.WriteFailure" },
-    { XFCONF_ERROR_PERMISSION_DENIED, "org.xfce.Xfconf.Error.PermissionDenied" },
-    { XFCONF_ERROR_INTERNAL_ERROR, "org.xfce.Xfconf.Error.InternalError" },
-    { XFCONF_ERROR_NO_BACKEND, "org.xfce.Xfconf.Error.NoBackend" },
-    { XFCONF_ERROR_INVALID_PROPERTY, "org.xfce.Xfconf.Error.InvalidProperty" },
-    { XFCONF_ERROR_INVALID_CHANNEL, "org.xfce.Xfconf.Error.InvalidChannel" },
+    { XFCONF_ERROR_UNKNOWN, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.Unknown" },
+    { XFCONF_ERROR_CHANNEL_NOT_FOUND, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.ChannelNotFound" },
+    { XFCONF_ERROR_PROPERTY_NOT_FOUND, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.PropertyNotFound" },
+    { XFCONF_ERROR_READ_FAILURE, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.ReadFailure" },
+    { XFCONF_ERROR_WRITE_FAILURE, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.WriteFailure" },
+    { XFCONF_ERROR_PERMISSION_DENIED, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.PermissionDenied" },
+    { XFCONF_ERROR_INTERNAL_ERROR, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.InternalError" },
+    { XFCONF_ERROR_NO_BACKEND, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.NoBackend" },
+    { XFCONF_ERROR_INVALID_PROPERTY, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.InvalidProperty" },
+    { XFCONF_ERROR_INVALID_CHANNEL, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.InvalidChannel" },
 };
 
 /**
