@@ -3,18 +3,19 @@
  *
  *  Copyright (c) 2007 Brian Tarricone <bjt23@cornell.edu>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License ONLY.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; version 2
+ *  of the License ONLY.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __XFCONF_H__
@@ -22,14 +23,14 @@
 
 #include <glib.h>
 
-#define XFCONF_IN_XFCONF_H
+#define __XFCONF_IN_XFCONF_H__
 
 #include <xfconf/xfconf-channel.h>
 #include <xfconf/xfconf-binding.h>
 #include <xfconf/xfconf-errors.h>
 #include <xfconf/xfconf-types.h>
 
-#undef XFCONF_IN_XFCONF_H
+#undef __XFCONF_IN_XFCONF_H__
 
 G_BEGIN_DECLS
 
