@@ -942,7 +942,7 @@ xfconf_proptree_build_propname(GNode *prop_node,
 
     for(cur = prop_node; cur; cur = cur->parent) {
         XfconfProperty *prop = cur->data;
-        if(!prop->name[1])  /* we've hit "/" */
+        if(prop->name[0] == '/')
             break;
         components = g_slist_prepend(components, prop->name);
     }
@@ -1019,7 +1019,7 @@ xfconf_backend_perchannel_xml_create_channel(XfconfBackendPerchannelXml *xbpx,
     prop = g_slice_new0(XfconfProperty);
     prop->name = g_strdup("/");
     channel->properties = g_node_new(prop);
-    g_hash_table_insert(xbpx->channels, g_ascii_strdown(channel_name, -1), channel);
+    g_hash_table_insert(xbpx->channels, g_strdup(channel_name), channel);
 
     return channel;
 }
@@ -1677,7 +1677,7 @@ xfconf_backend_perchannel_xml_load_channel(XfconfBackendPerchannelXml *xbpx,
                                                  channel, NULL);
     }
 
-    g_hash_table_insert(xbpx->channels, g_ascii_strdown(channel_name, -1), channel);
+    g_hash_table_insert(xbpx->channels, g_strdup(channel_name), channel);
 
 out:
     g_strfreev(filenames);
